@@ -1,18 +1,34 @@
+import base64
 import json
+
 from urllib.request import Request, urlopen
 from urllib.error import HTTPError, URLError
 
 
 class RippleRPCClient(object):
-    def __init__(self, node: str):
+    def __init__(self, node: str, username: str = None, password: str = None):
         """
         :param node: URL of rippled node
+        :param username: username of admin in rippled node
+        :param password: password of admin in rippled node
         """
         self.node = node
+        self.username = username
+        self.password = password
 
     def __repr__(self):
         return '<RippleRPCClient node=%r>' % self.node
 
+    @property
+    def request_headers(self):
+        headers = {'Content-Type': 'application/json'}
+        if self.username and self.password:
+            string = '{}:{}'.format(self.username, self.password)
+            base64string = base64.standard_b64encode(
+                string.encode('utf-8')).decode('utf-8')
+            headers.update({'Authorization': 'Basic {}'.format(base64string)})
+        return headers
+
     def _call(self, method: str, params: dict) -> dict:
         """Base method which sends requests to node
         :param method: JSON-RPC method of rippled
@@ -25,7 +41,7 @@ class RippleRPCClient(object):
             ]
         }).encode('utf-8')
         req = Request(method='POST', url=self.node,
-                      data=payload, headers={'Content-Type': 'application/json'})
+                      data=payload, headers=self.request_headers)
         try:
             with urlopen(req) as res:
                 res_json = json.loads(res.fp.read().decode('utf-8'))
@@ -423,7 +439,7 @@ class RippleRPCClient(object):
         """
         return self._call('validation_create', params=dict(secret=secret))
 
-    def wallet_propose(self, seed: str, passphrase: str, key: str="secp256k1") -> dict:
+    def wallet_propose(self, seed: str='', passphrase: str='', key: str="secp256k1") -> dict:
         """
         Method to generate a key pair and XRP Ledger address.
         This command only generates key and address values, and does not affect the XRP Ledger itself in any way.
@@ -431,13 +447,12 @@ class RippleRPCClient(object):
         Reference: https://developers.ripple.com/wallet_propose.html
         """
         params = dict(
-            seed=seed,
             key=key
         )
+        if seed:
+            params['seed'] = seed
         if passphrase:
-            params = dict(
-                passphrase=passphrase
-            )
+            params['passphrase'] = passphrase
         return self._call('wallet_propose', params)
 
     def can_delete(self, can_delete: int) -> dict:
